@@ -4,8 +4,10 @@ import Test.Tasty.Runners.AntXML
 
 import qualified Test.Context
 import qualified Test.Fin
+import qualified Test.FinMap
 import qualified Test.List
 import qualified Test.NatRepr
+import qualified Test.Some
 import qualified Test.SymbolRepr
 import qualified Test.TH
 import qualified Test.Vector
@@ -25,7 +27,9 @@ tests = testGroup "ParameterizedUtils" <$> sequence
   [ Test.Context.contextTests
   , pure Test.List.tests
   , Test.Fin.finTests
+  , Test.FinMap.finMapTests
   , Test.NatRepr.natTests
+  , Test.Some.someTests
   , Test.SymbolRepr.symbolTests
   , Test.TH.thTests
   , Test.Vector.vecTests
